Bring Erlang's DNS record definitions into Elixir
Summary
Functions
Decode a packet that contains a DNS message
Encode a DNS record
Format a DNS record as a nice string for the user
Types
Functions
Decode a packet that contains a DNS message
Encode a DNS record
Format a DNS record as a nice string for the user